:mod:`art.attacks.inference.membership_inference`
=================================================
.. automodule:: art.attacks.inference.membership_inference

Membership Inference Black-Box
------------------------------
.. autoclass:: MembershipInferenceBlackBox
   :members:
   :special-members:

Membership Inference Black-Box Rule-Based
-----------------------------------------
.. autoclass:: MembershipInferenceBlackBoxRuleBased
   :members:
   :special-members:
